@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017,2019 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -50,7 +50,8 @@ namespace gnote {
   void NoteManager::init(const Glib::ustring & directory)
   {
     Glib::ustring backup = directory + "/Backup";
-    bool is_first_run = NoteManagerBase::init(directory, backup);
+    NoteManagerBase::init(directory, backup);
+    bool is_first_run = first_run();
 
     Glib::RefPtr<Gio::Settings> settings = m_preferences.get_schema_settings(Preferences::SCHEMA_GNOTE);
     // Watch the START_NOTE_URI setting and update it so that the
@@ -272,15 +273,14 @@ namespace gnote {
   }
 
 
-  // Create a new note with the specified title from the default
-  // template note. Optionally the body can be overridden.
-  NoteBase::Ptr NoteManager::create_new_note(Glib::ustring title, const Glib::ustring & guid)
+  NoteBase::Ptr NoteManager::create_note(Glib::ustring title, Glib::ustring body, const Glib::ustring & guid)
   {
-    NoteBase::Ptr new_note = NoteManagerBase::create_new_note(title, guid);
-
-    // Select the inital text so typing will overwrite the body text
-    std::static_pointer_cast<Note>(new_note)->get_buffer()->select_note_body();
-
+    bool select_body = body.empty();
+    auto new_note = NoteManagerBase::create_note(std::move(title), std::move(body), guid);
+    if(select_body) {
+      // Select the inital text so typing will overwrite the body text
+      std::static_pointer_cast<Note>(new_note)->get_buffer()->select_note_body();
+    }
     return new_note;
   }
 
