@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2016-2017,2019 Aurimas Cernius
+ * Copyright (C) 2010-2014,2016-2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -101,7 +101,7 @@ NoteManagerBase::~NoteManagerBase()
   }
 }
 
-bool NoteManagerBase::init(const Glib::ustring & directory, const Glib::ustring & backup_directory)
+void NoteManagerBase::init(const Glib::ustring & directory, const Glib::ustring & backup_directory)
 {
   m_notes_dir = directory;
   m_default_note_template_title = _("New Note Template");
@@ -123,7 +123,6 @@ bool NoteManagerBase::init(const Glib::ustring & directory, const Glib::ustring
   }
 
   m_trie_controller = create_trie_controller();
-  return is_first_run;
 }
 
 bool NoteManagerBase::first_run() const
@@ -238,12 +237,14 @@ NoteBase::Ptr NoteManagerBase::create_note_from_template(const Glib::ustring & t
 
 NoteBase::Ptr NoteManagerBase::create()
 {
-  return create("");
+  return create_note("", "");
 }
 
 NoteBase::Ptr NoteManagerBase::create(const Glib::ustring & title)
 {
-  return create_new_note(title, "");
+  Glib::ustring body;
+  auto note_title = split_title_from_content(title, body);
+  return create_note(note_title, body);
 }
 
 NoteBase::Ptr NoteManagerBase::create(const Glib::ustring & title, const Glib::ustring & xml_content)
@@ -296,33 +297,28 @@ Glib::ustring NoteManagerBase::get_unique_name(const Glib::ustring & basename) c
   return title;
 }
 
-// Create a new note with the specified title from the default
-// template note. Optionally the body can be overridden.
-NoteBase::Ptr NoteManagerBase::create_new_note(Glib::ustring title, const Glib::ustring & guid)
+NoteBase::Ptr NoteManagerBase::create_note(Glib::ustring title, Glib::ustring body, const Glib::ustring & guid)
 {
-  Glib::ustring body;
-
-  title = split_title_from_content(title, body);
-
   if(title.empty()) {
     title = get_unique_name(_("New Note"));
   }
 
-  NoteBase::Ptr template_note = get_or_create_template_note();
-
+  Glib::ustring content;
   if(body.empty()) {
-    return create_note_from_template(title, template_note, guid);
+    auto template_note = find_template_note();
+    if(template_note) {
+      return create_note_from_template(title, template_note, guid);
+    }
+
+    // Use a simple "Describe..." body and highlight
+    // it so it can be easily overwritten
+    content = get_note_template_content(title);
+  }
+  else {
+    content = get_note_content(title, body);
   }
 
-  // Use a simple "Describe..." body and highlight
-  // it so it can be easily overwritten
-  Glib::ustring content = get_note_template_content(title);
-  NoteBase::Ptr new_note = create_new_note(title, content, guid);
-
-  // Select the inital text so typing will overwrite the body text
-  std::static_pointer_cast<Note>(new_note)->get_buffer()->select_note_body();
-
-  return new_note;
+  return create_new_note(title, content, guid);
 }
 
 // Create a new note with the specified Xml content
@@ -357,13 +353,18 @@ NoteBase::Ptr NoteManagerBase::create_new_note(const Glib::ustring & title, cons
 }
 
 Glib::ustring NoteManagerBase::get_note_template_content(const Glib::ustring & title)
+{
+  return get_note_content(title, _("Describe your new note here."));
+}
+
+Glib::ustring NoteManagerBase::get_note_content(const Glib::ustring & title, const Glib::ustring & body)
 {
   return Glib::ustring::compose("<note-content>"
                                   "<note-title>%1</note-title>\n\n"
                                   "%2"
                                 "</note-content>",
              utils::XmlEncoder::encode(title),
-             _("Describe your new note here."));
+             utils::XmlEncoder::encode(body));
 }
 
 NoteBase::Ptr NoteManagerBase::get_or_create_template_note()
@@ -504,7 +505,9 @@ NoteBase::Ptr NoteManagerBase::import_note(const Glib::ustring & file_path)
 
 NoteBase::Ptr NoteManagerBase::create_with_guid(const Glib::ustring & title, const Glib::ustring & guid)
 {
-  return create_new_note(title, guid);
+  Glib::ustring body;
+  auto note_title = split_title_from_content(title, body);
+  return create_note(note_title, body, guid);
 }
 
 
