@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017,2019 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -45,6 +45,7 @@ public:
 
   static Glib::ustring sanitize_xml_content(const Glib::ustring & xml_content);
   static Glib::ustring get_note_template_content(const Glib::ustring & title);
+  static Glib::ustring get_note_content(const Glib::ustring & title, const Glib::ustring & body);
   static Glib::ustring split_title_from_content(Glib::ustring title, Glib::ustring & body);
 
   NoteManagerBase(IGnote & g);
@@ -101,7 +102,8 @@ public:
   NoteBase::RenamedHandler signal_note_renamed;
   NoteBase::SavedHandler signal_note_saved;
 protected:
-  bool init(const Glib::ustring & directory, const Glib::ustring & backup);
+  void init(const Glib::ustring & directory, const Glib::ustring & backup);
+  bool first_run() const;
   virtual void post_load();
   virtual void migrate_notes(const Glib::ustring & old_note_dir);
   /** add the note to the manager and setup signals */
@@ -111,7 +113,7 @@ protected:
   virtual NoteBase::Ptr create_note_from_template(const Glib::ustring & title,
                                                   const NoteBase::Ptr & template_note,
                                                   const Glib::ustring & guid);
-  virtual NoteBase::Ptr create_new_note(Glib::ustring title, const Glib::ustring & guid);
+  virtual NoteBase::Ptr create_note(Glib::ustring title, Glib::ustring body, const Glib::ustring & guid = Glib::ustring());
   virtual NoteBase::Ptr create_new_note(const Glib::ustring & title, const Glib::ustring & xml_content, 
                                         const Glib::ustring & guid);
   virtual NoteBase::Ptr note_create_new(const Glib::ustring & title, const Glib::ustring & file_name) = 0;
@@ -125,7 +127,6 @@ protected:
   Glib::ustring m_backup_dir;
   Glib::ustring m_default_note_template_title;
 private:
-  bool first_run() const;
   void create_notes_dir() const;
   bool create_directory(const Glib::ustring & directory) const;
   TrieController *create_trie_controller();
